@@ -69,6 +69,10 @@ class QueenbeeTask(luigi.Task):
                             'completed': 0,
                             'running': 0,
                             'total': 0
+                        },
+                        'resources_duration': {
+                            'cpu': 0,
+                            'memory': 0
                         }
                     }
                 })
@@ -102,6 +106,12 @@ class QueenbeeTask(luigi.Task):
             logging.config.fileConfig(self.log_config)
         return logger
 
+    def get_queenbee_errors_logger(self):
+        logger = logging.getLogger('queenbee-error')
+        if not logger.handlers:
+            logging.config.fileConfig(self.log_config)
+        return logger
+
     @property
     def input_artifacts(self):
         """Task's input artifacts.
@@ -268,6 +278,7 @@ class QueenbeeTask(luigi.Task):
         st_time = datetime.now()
         logger = self.get_interface_logger()
         qb_logger = self.get_queenbee_logger()
+        err_logger = self.get_queenbee_errors_logger()
         # replace ' with " for Windows systems and vise versa for unix systems
         command = self.command()
         if SYSTEM == 'Windows':
@@ -303,6 +314,7 @@ class QueenbeeTask(luigi.Task):
             stderr=subprocess.STDOUT, shell=True, env=os.environ
         )
 
+        msg = ''
         for line in iter(p.stdout.readline, b''):
             msg = line.decode('utf-8').strip()
             logger.info(msg)
@@ -311,10 +323,11 @@ class QueenbeeTask(luigi.Task):
         p.communicate()
 
         if p.returncode != 0:
-            err_msg = f'\n\nFailed task: {self.__class__.__name__}.\n' \
-                'Run the command with --debug key to debug the workflow.\n\n'
+            err_msg = f'"{self.__class__.__name__}" failed. See below for more ' \
+                f'information:\n\n    {msg}\n'
             qb_logger.error(err_msg)
             logger.error(err_msg)
+            err_logger.error(err_msg)
             self._update_status(logger=qb_logger, started=False)
             raise ValueError(err_msg)
 
@@ -336,7 +349,9 @@ class QueenbeeTask(luigi.Task):
         duration -= timedelta(microseconds=duration.microseconds)  # remove microseconds
         logger.info(f'...finished running {self.__class__.__name__} in {duration}')
         qb_logger.info(f'...finished running {self.__class__.__name__} in {duration}')
-        self._update_status(logger=qb_logger, started=False)
+        self._update_status(
+            logger=qb_logger, started=False, cpu_seconds=duration.seconds
+        )
 
     @staticmethod
     def load_input_param(input_param):
@@ -351,7 +366,7 @@ class QueenbeeTask(luigi.Task):
         )
         return load_input_param(input_param)
 
-    def _update_status(self, logger, started=True):
+    def _update_status(self, logger, started=True, cpu_seconds=0):
         """Update run status."""
         if not hasattr(self, '_status_lock'):
             warnings.warn(
@@ -363,15 +378,26 @@ class QueenbeeTask(luigi.Task):
             # open JSON file
             inf = self.status_file()
             # update values
-            data = json.loads(inf.read_text())
+            try:
+                data = json.loads(inf.read_text())
+            except json.JSONDecodeError:
+                # this should not happen unless user directly interacts with the status
+                # file and blocks the status update
+                return
+            data['meta']['resources_duration']['cpu'] += cpu_seconds
             progress = data['meta']['progress']
             if started:
                 progress['running'] += 1
                 progress['total'] += 1
             else:
                 # task finished
-                progress['running'] -= 1
+                if progress['running'] > 0:
+                    # apparently this can happen is complicated workflows.
+                    # I can spend hours to replicate and fix this issue but it is not
+                    # really critical. This small fix will make it look reasonable.
+                    progress['running'] -= 1
                 progress['completed'] += 1
+
             # write the json file
             logger.info(
                 f'[{progress["completed"]}/{progress["total"]}] completed. '
@@ -429,10 +455,10 @@ LOGS_CONFIG = """
 keys: default
 
 [loggers]
-keys: root, luigi-interface, queenbee-interface
+keys: root, luigi-interface, queenbee-interface, queenbee-error
 
 [handlers]
-keys: console, logfile
+keys: console, logfile, errfile
 
 [formatter_default]
 format: %(asctime)s %(levelname)s: %(message)s
@@ -450,8 +476,14 @@ args: ['WORKFLOW.LOG',]
 formatter: default
 level: DEBUG
 
+[handler_errfile]
+class: FileHandler
+args: ['ERROR.LOG',]
+formatter: default
+level: ERROR
+
 [logger_root]
-handlers: logfile
+handlers: errfile, logfile
 qualname: root
 propagate=0
 
@@ -461,6 +493,12 @@ qualname: luigi-interface
 propagate=0
 level: DEBUG
 
+[logger_queenbee-error]
+handlers: errfile
+qualname: queenbee-error
+propagate=0
+level: ERROR
+
 [logger_queenbee-interface]
 handlers: console
 qualname: queenbee-interface
